@@ -12,6 +12,6 @@ end_activities_resource <- function(eventlog) {
 		arrange(desc(absolute)) %>%
 		mutate(relative = absolute/n_cases(eventlog),
 			   cum_sum = cumsum(relative)) %>%
-		return()
+		arrange(!!resource_id_(eventlog))
 
 }
