@@ -1,9 +1,10 @@
 
 
 processing_time_log <- function(eventlog,
-								units) {
+								units,
+								work_schedule) {
 
-	raw <- processing_time_case(eventlog, units = units)
+	raw <- processing_time_case(eventlog, units = units, work_schedule = work_schedule)
 
 	raw %>%
 		pull(processing_time) %>%
